/*******************************************************************************
 * Copyright (c) 2006 Novell, Inc..
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *    Jim Sermersheim - Initial cut of interfaces agreed upon 20060707
 *******************************************************************************/

package org.eclipse.higgins.idas;

import java.net.URI;

/**
 * As defined at <a href="http://spwiki.editme.com/ContextProvider#ContextFactory"/>http://spwiki.editme.com/ContextProvider#ContextFactory</a>, This interface is implemented by IdAS context providers so that their {@link IContext} instances may be instantiated.<p> 
 * TODO (Arch)(Doc): Talk about what's required to make this work -- how factories are registered and referenced in the Higgins system.<p>
 * TODO (Doc): Finish commenting methods. 
 */
public interface IContextFactory extends IHasMetadata
{
	public String getName() throws IdASException;

	/**
	 *
	 * @param filter Format TBD
	 * @return The set of Context References of Contexts which have been created by this Context Factory  
	 * @throws IdASException
	 */
	public Iterable<URI> getContexts(String filter) throws IdASException;
	
	/**
	 * Tests whether the asserted Context Reference can be used by this factory to produce an {@link IContext} instance.
	 * @param contextRef URI specifying the Context being tested.
	 * @return true if this factory can produce a context for the passed contextRef
	 * @throws IdASException
	 */
	public boolean canCreate(URI contextRef) throws IdASException;
	
	/**
	 * Using contextRef, creates an instance of {@link IContext} and returns it.
	 * @param contextRef URI specifying the Context to create.
	 * @return An IContext instance appropriate for the contextRef.
	 * @throws IdASException
	 */
	public IContext createContext(URI contextRef) throws IdASException;

	/**
	 * Returns the policy in effect for this Context Factory.
	 * @return Format is WS-Policy / WS-SecurityPolicy<p>
	 * @throws IdASException
	 * TODO (Arch)(Doc): Describe format in more detail. Give examples.
	 */
	public String getPolicy() throws IdASException;

	/**
	 * Sets the policy for for this Context Factory.
	 * @param policy Format is WS-Policy / WS-SecurityPolicy<p>
	 * @throws IdASException
	 * TODO (Arch)(Doc): Describe format in more detail. Give examples.
	 */
	public void	setPolicy(String policy) throws IdASException;
}
