/*******************************************************************************
 * Copyright (c) 2006 Novell, Inc..
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *    Jim Sermersheim - Initial cut of interface agreed upon 20060814
 *******************************************************************************/
package org.eclipse.higgins.idas;

import java.net.URI;

/**
 * Represents a reference to a Digital Subject.<p>
 * This reference contains both the reference to the Context containing the Digital Subject
 * as well as the contextually unique id of the Digital Subject.<p>
 * This is used in Digital Subject Relationships.
 */
public interface IDigitalSubjectRef {

	/**
	 * Returns a reference to the Context holding the referred-to {@link IDigitalSubject}.
	 * 
	 * @return the reference to the Digital Subject's Context.
	 * @throws IdASException
	 */
	public URI getContextRef() throws IdASException;
	
	/**
	 * Returns the Contextually Unique Identifier of the referred-to {@link IDigitalSubject}.
	 * 
	 * @return Contextually Unique Identifier of the Digital Subject
	 * @throws IdASException
	 */
	public String getUniqueID() throws IdASException;
	
}
