/*******************************************************************************
 * Copyright (c) 2006 Novell, Inc..
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *    Jim Sermersheim - Initial cut of interfaces agreed upon 20061005
 *******************************************************************************/

package org.eclipse.higgins.idas;

import org.eclipse.higgins.idas.IdASException;

/**
 * Intended to be a super-interface to {@link org.eclipse.higgins.idas.IFilterAttributeAssertion} and {@link org.eclipse.higgins.idas.IFilterMetadataAssertion}<br>
 * Represents a filter assertion about properties of a Digital Subject.<br> 
 * This assertion is made up of a comparator (operator), property type and assertion value.<p>
 *  
 * The particular type and form of the IPropertyValue used as an assertion is dictated by the comparator and the property type.
 * In other words, a particular property type will specify the comparators valid for that type, as well as the format of assertion value for each valid comparator.
 * TODO (Doc): Refer to example specifications for this
 */
public abstract interface IFilterPropertyAssertion extends IFilterAssertion {
	/**
	 * Compares true when the specified property type is present in a tested Digital Subject.<p>
	 * An assertion value is not specified.<P>
	 * Value: {@value}
	 */
	public static final String COMP_PROP_PRESENT = "urn:org.eclipse.higgins.idas.comparator.property.present";

	/**
	 * Compares true when a tested Digital Subject has a property of the specified type which contains at least one value equal to the specified assertion value.<P> 
	 * Value: {@value}
	 */
	public static final String COMP_PROP_EQ = "urn:org.eclipse.higgins.idas.comparator.property.equality";

	/**
	 * Compares true when a tested Digital Subject has a property of the specified type which contains at least one value greater or equal to the specified assertion value.<P> 
	 * Value: {@value}
	 */
	public static final String COMP_PROP_GE = "urn:org.eclipse.higgins.idas.comparator.property.greaterOrEqual";

	/**
	 * Compares true when a tested Digital Subject has a property of the specified type which contains at least one value less or equal to the specified assertion value.<P>
	 * Value: {@value}
	 */
	public static final String COMP_PROP_LE = "urn:org.eclipse.higgins.idas.comparator.property.lessOrEqual";

	/**
	 * Compares true when a tested Digital Subject has a property of the specified type which contains at least one value containing the substring specified by the assertion value.<P> 
	 * Value: {@value}
	 */
	public static final String COMP_PROP_SUBSTR = "urn:org.eclipse.higgins.idas.comparator.property.substring";
	
	/**
	 * Specifies the assertion data to be tested against values of a Digital Subject's properties.
	 * 
	 * To specify an assertion value nested in a complex type (like a postalAddress.city of "Provo"), 
	 * one would pass in an IComplexValue with the property(ies) containing 
	 * the assertion(s). i.e. the IFilterPropertyAssertion would have a type like "urn:postalAddress" 
	 * and the assertionValue would be an IComplexValue containing a property. That property 
	 * would have a type like "urn:city", and would have an ISimpleValue containing the assertion "Provo"
	 * 
	 * This allows multiple parts of a complex value to be asserted such that one may specify a filter like
	 * postalAddress.city = "Provo" AND postalAddress.state = "Utah", where both assertions have to 
	 * match the same postalAddress value.
	 * 
	 */
	public void setAssertionValue(IPropertyValue assertion) throws IdASException;

}
