/*******************************************************************************
 * Copyright (c) 2006 Novell, Inc..
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *    Jim Sermersheim - Initial cut
 *******************************************************************************/

package org.eclipse.higgins.idas;

/**
 * Represents a filter assertion about the relationships of a Digital Subject.<br> 
 * This assertion is made up of a comparator (operator), relationship type and digital subject reference.<p>
 *  
 */
public interface IFilterRelationshipAssertion extends IFilterAssertion {
	/**
	 * Compares true when the specified relationship type is present in a tested Digital Subject.<p>
	 * An assertion value is not specified.<P>
	 * Value: {@value}
	 */
	public static final String COMP_REL_PRESENT = "urn:org.eclipse.higgins.idas.comparator.relationship.present";

	/**
	 * Compares true when a tested Digital Subject has a relationship of the specified type and has a digital subject reference matching the assertion value.<P> 
	 * Value: {@value}
	 */
	public static final String COMP_REL_EQ = "urn:org.eclipse.higgins.idas.comparator.relationship.equality";

	/**
	 * Compares true when a tested Digital Subject has the asserted relationship (of the asserted type) whether that relationship is implied or explicit.<p>
	 * For example, if the assertion specified a type of "urn:parentOf" and reference of {"someContext", "urn:Mary"} it could result in a match because either:<br>
	 * A subject has a relationship of type "urn:parentOf" and reference of {"someContext", "urn:Mary"), or<br>
	 * A subject is referenced by the subject "urn:Mary" in the context "someContext" where the referencing relationship is of type "urn:childOf" (assuming the ontology backing the context provides the proper inferences between parentOf and childOf)<p>  
	 * Value: {@value}
	 */
	public static final String COMP_REL_IMPLIED_EQ = "urn:org.eclipse.higgins.idas.comparator.relationship.impliedequality";

	/**
	 * Adds a relationship metadata filter to this relationship assertion.
	 * @param metadataFilter An optional filter, specifying relationship metadata 
	 * 						which must match for this assertion to match.
	 * 						This allows one to differentiate between two relationships 
	 * 						of the same type where the metadata differs. 
	 */
	public void setMetadataFilter(IFilter metadataFilter) throws IdASException;

	/**
	 * Specifies the assertion data (context references) to be tested against values of a Digital Subject's relationships.
	 * 
	 */
	public void setAssertionValue(IDigitalSubjectRef assertion) throws IdASException;
}
