/*******************************************************************************
 * Copyright (c) 2006 Novell, Inc..
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *    Jim Sermersheim - Initial cut of interface
 *******************************************************************************/

package org.eclipse.higgins.idas;

import java.net.URI;

/**
 */
public interface IHasAttributes
{
	/**
	 * Creates and adds an attribute for this object.
	 * @param type The attribute's type.
	 * @param value The attribute's value.
	 * @return The resulting Attribute.
	 * @throws IdASException
	 */
	public IAttribute createAttribute(URI type, IPropertyValue value) throws IdASException;
	
	/**
	 * Creates and adds an attribute for this object.
	 * @param type The attribute's type.
	 * @param values The attribute's values.
	 * @return The resulting Attribute.
	 * @throws IdASException
	 */
	public IAttribute createAttribute(URI type, Iterable<IPropertyValue> values) throws IdASException;

	public void	addAttribute(IAttribute attribute) throws IdASException;

	public void	removeAttribute(IAttribute attribute) throws IdASException;

	/**
	 * Return all attributes of this object<p>
	 * 
	 * @return An {@link Iterable} object of {@link IAttribute}s.
	 * @throws IdASException
	 */
	public Iterable<IAttribute> getAttributes() throws IdASException;
	
	/**
	 * Return specified attribute of this object<p>
	 *
	 * @param attrID The identifier of the attribute to be returned.
	 * @return An {@link IAttribute} or {@code null} if none exits.
	 * @throws IdASException
	 */
	public IAttribute getAttribute(URI attrID) throws IdASException;

}
