/*******************************************************************************
 * Copyright (c) 2006 Novell, Inc..
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *    Jim Sermersheim - Initial cut of interfaces agreed upon 20060707
 *******************************************************************************/

package org.eclipse.higgins.idas;

import java.net.URI;

/**
 * Extended by interfaces which have metadata associated with them.<p>
 * TODO (Doc): Add (or point to) doc which explains metadata.
 *
 */
public interface IHasMetadata {

	/**
	 * Creates a metadata item which can be added to metadata held by this Object.
	 * @param type The type of metadata. This defines the datatype of the value.
	 * @param value The value of this metadata. The type of this is determined by the type argument.
	 * @return The created metadata item.
	 * @throws IdASException
	 * TODO (Arch)(Doc): Specify whether this also adds the produced IMetadata to this Object, or if addItem must subsequently be called.<p>
	 * TODO (Doc): If this method also adds, note that updates to the returned IMetadata affect the added item (i.e. a reference, not a copy is stored).<p>
	 */
	public IMetadata createMetadata(URI type, IPropertyValue value) throws IdASException;

	public void	addMetadata(IMetadata metadata) throws IdASException;
	public void	removeMetadata(IMetadata metadata) throws IdASException;

	/**
	 * Returns this Object's metadata elements as an Iterable.
	 * TODO (Arch): Consider overloading to take a metadata type (gets all metadata of that type) 
	 * @throws IdASException
	 */
	public Iterable<IMetadata> getMetadataSet() throws IdASException;

}
