/*******************************************************************************
 * Copyright (c) 2006 Novell, Inc..
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *    Jim Sermersheim - Initial cut of interface
 *******************************************************************************/

package org.eclipse.higgins.idas;

import java.net.URI;

/**
 */
public interface IHasProperties
{
	/**
	 * Creates and adds a property for this object.
	 * @param type The property's type.
	 * @param value The property's value.
	 * @return The resulting Property.
	 * @throws IdASException
	 */
	public IProperty createProperty(URI type, IPropertyValue value) throws IdASException;
	
	/**
	 * Creates and adds a property for this object.
	 * @param type The property's type.
	 * @param values The property's values.
	 * @return The resulting Property.
	 * @throws IdASException
	 */
	public IProperty createProperty(URI type, Iterable<IPropertyValue> values) throws IdASException;

	public void	addProperty(IProperty property) throws IdASException;

	public void	removeProperty(IProperty property) throws IdASException;

	/**
	 * Return all Properties of this object<p>
	 * 
	 * @return An {@link Iterable} object of {@link IProperty}s.
	 * @throws IdASException
	 */
	public Iterable<IProperty> getProperties() throws IdASException;
	
	/**
	 * Return specified property of this object<p>
	 *
	 * @param type The identifier of the property to be returned.
	 * @return An {@link IProperty} or {@code null} if none exits.
	 * @throws IdASException
	 */
	public IProperty getProperty(URI type) throws IdASException;

}
