/*******************************************************************************
 * Copyright (c) 2006 Novell, Inc..
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *    Jim Sermersheim - Initial cut of interfaces agreed upon 20060707
 *******************************************************************************/

package org.eclipse.higgins.idas;

import java.net.URI;

/**
 * Extended by interfaces which have relationships to other objects.<p>
 *
 * @param <T> 	The type of object used to represent the relationship. This is typically an identifier.<p>
 * 				This type is used to type the uses of {@link IRelationship} in this interface.
 */
public interface IHasRelationships <T> {

	/**
	 * Creates a relationship to another Object.<p>
	 * TODO (Arch)(Doc): Specify whether this also adds the relationship to this Object, or if add must subsequently be called.<p>
	 * TODO (Arch)(Doc): If this method also adds, note that updates to the returned {@link IRelationship} affect the added relationship.<p>
	 * @param type The type of relationship. TODO (Doc): give example.
	 * @return The resulting Relationship.
	 * @throws IdASException
	 */
	public IRelationship<T> createRelationship(URI type) throws IdASException;
	
	/**
	 * Adds the specified Relationship to this Object.
	 * @param relationship The Relationship to add.
	 * @throws IdASException
	 */
	public void	addRelationship(IRelationship<T> relationship) throws IdASException;

	/**
	 * Removes the specified Relationship from this Object.<p>
	 * TODO (Arch): How does the Service Provider match relationships in order to do the remove?
	 * @param relationship The Relationship to remove.
	 * @throws IdASException
	 */
	public void removeRelationship(IRelationship<T> relationship) throws IdASException;

	/**
	 * Returns the relationships this Object has to others.
	 * @return The set of Relationships this Object has.
	 * @throws IdASException
	 */
	public Iterable<IRelationship<T>> getRelationships() throws IdASException;
}
