/*******************************************************************************
 * Copyright (c) 2006 Novell, Inc..
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *    Jim Sermersheim - Initial cut of interfaces agreed upon 20060707
 *******************************************************************************/

package org.eclipse.higgins.idas;

import java.net.URI;

/**
 * Represents a typed value (or values).<p>
 *
 */
public interface IProperty {
	
	/**
	 * Returns the type of this property as a {@link URI}.<p>
	 * From this URI, a consumer should be able to derive some kind of human-readable name (such as "age", "title", "employeeNumber", etc.).<p>
	 * A consumer might also be able to determine from this URI, the type or range of types of object(s) returned from {@link #getValue()} and {@link #getValues()}.<p>
	 * These determinations may be made either by examining parts of the URI itself, or dereferencing it (or parts) to other sources of information.<p>
	 * @throws IdASException
	 */
	public URI getType() throws IdASException;
	

	/**
	 * Returns a single value for this iProperty. In the case where this property has multiple values, the particular value returned is indeterminate.
	 * @throws IdASException
	 */
	public IPropertyValue getValue() throws IdASException;

	/**
	 * Returns all values for this iProperty.
	 * @throws IdASException
	 */
	public Iterable<IPropertyValue> getValues() throws IdASException;

	/**
	 * @throws IdASException
	 */
	public void setValue(IPropertyValue value) throws IdASException;

}
