/*******************************************************************************
 * Copyright (c) 2006 Novell, Inc..
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *    Jim Sermersheim - Initial cut of interface
 *******************************************************************************/

package org.eclipse.higgins.idas;

import java.net.URI;

/**
 * Holds the value of a property.<p>
 * When the value is a Literal ({@link #isSimple()} returns true), an instance of this interface may be cast to {@link ISimpleValue}, and the table found at {@link ISimpleValue#getData()} is used to determine the type returned from {@link ISimpleValue#getData()}.    
 * When the value is a Resource ({@link #isSimple()} returns false), an instance of this interface may be cast to {@link IComplexValue}.    
 */
public interface IPropertyValue {
	public static final String BASE_OWL_URI = "http://www.eclipse.org/higgins/ontologies/2006/higgins"; 
	
	/**
	 * @throws IdASException
	 */
	public boolean isSimple() throws IdASException;
	
	/**
	 * TODO (Doc): refer to an example like those found at http://wiki.eclipse.org/index.php/Person-with-address_Example_Context_Ontology
	 * @return The OWL type for this property's value (i.e. xml:string).
	 * @throws IdASException
	 */
	public URI getType()throws IdASException;
	
	/**
	 * Returns the backing Java object for this property value.<p>
	 * TODO (Arch): This method is a temporary hack to solve the issue brought up in this <A href="http://dev.eclipse.org/mhonarc/lists/higgins-dev/msg00694.html">thread</A>.
	 * @throws IdASException
	 */
	public Object getData() throws IdASException;

}
