/*******************************************************************************
 * Copyright (c) 2006 Novell, Inc..
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *    Jim Sermersheim - Initial cut of interface
 *******************************************************************************/

package org.eclipse.higgins.idas;

import java.net.URI;

import org.eclipse.higgins.idas.impl.BasicValueBase64Binary;
import org.eclipse.higgins.idas.impl.BasicValueBoolean;
import org.eclipse.higgins.idas.impl.BasicValueByte;
import org.eclipse.higgins.idas.impl.BasicValueDate;
import org.eclipse.higgins.idas.impl.BasicValueDateTime;
import org.eclipse.higgins.idas.impl.BasicValueGDay;
import org.eclipse.higgins.idas.impl.BasicValueDecimal;
import org.eclipse.higgins.idas.impl.BasicValueDouble;
import org.eclipse.higgins.idas.impl.BasicValueFloat;
import org.eclipse.higgins.idas.impl.BasicValueHexBinary;
import org.eclipse.higgins.idas.impl.BasicValueInteger;
import org.eclipse.higgins.idas.impl.BasicValueLanguage;
import org.eclipse.higgins.idas.impl.BasicValueLong;
import org.eclipse.higgins.idas.impl.BasicValueGMonth;
import org.eclipse.higgins.idas.impl.BasicValueGMonthDay;
import org.eclipse.higgins.idas.impl.BasicValueNCName;
import org.eclipse.higgins.idas.impl.BasicValueNMTOKEN;
import org.eclipse.higgins.idas.impl.BasicValueName;
import org.eclipse.higgins.idas.impl.BasicValueNegativeInteger;
import org.eclipse.higgins.idas.impl.BasicValueNonNegativeInteger;
import org.eclipse.higgins.idas.impl.BasicValueNonPositiveInteger;
import org.eclipse.higgins.idas.impl.BasicValueNormalizedString;
import org.eclipse.higgins.idas.impl.BasicValuePositiveInteger;
import org.eclipse.higgins.idas.impl.BasicValueShort;
import org.eclipse.higgins.idas.impl.BasicValueString;
import org.eclipse.higgins.idas.impl.BasicValueTime;
import org.eclipse.higgins.idas.impl.BasicValueToken;
import org.eclipse.higgins.idas.impl.BasicValueAnyURI;
import org.eclipse.higgins.idas.impl.BasicValueUnsignedByte;
import org.eclipse.higgins.idas.impl.BasicValueUnsignedInt;
import org.eclipse.higgins.idas.impl.BasicValueUnsignedLong;
import org.eclipse.higgins.idas.impl.BasicValueUnsignedShort;
import org.eclipse.higgins.idas.impl.BasicValueGYear;
import org.eclipse.higgins.idas.impl.BasicValueGYearMonth;

/**
 * 
 *
 */
public interface ISimpleValue extends IPropertyValue {
	public static final String BASE_XML_SCHEMA_URI = "http://www.w3.org/2001/XMLSchema#"; 

	/**
	 * Returns a lexical representation if this value is a literal
	 * @throws IdASException
	 */
	public String getLexical() throws IdASException;
	
	/**
	 * Returns the canonical representation if this value is a literal
	 * @throws IdASException
	 */
	public String getCanonical() throws IdASException;

	/**
	 * Returns the underlying Java object holding this simple type's value.<p>
	 * This table specifies the mappings between Higgins OWL datatypes (in the higgins ontology http://www.eclipse.org/higgins/ontologies/2006/higgins), XML schema types (in the http://www.w3.org/2001/XMLSchema namespace), Java classes (returned by {@link #getData()}), and IdAS basic value implementations.
	 * <table border="1" >
	 * <tr><th>Higgins OWL type<th>XML schema type<th>Java class<th>Basic Implementation 
	 * <tr><td>{@value org.eclipse.higgins.idas.impl.BasicValueString#OWL_TYPE_STR}</td><td>{@value org.eclipse.higgins.idas.impl.BasicValueString#XML_TYPE_STR}</td><td>{@link String}</td><td>{@link BasicValueString}</td></tr>
	 * <tr><td>{@value org.eclipse.higgins.idas.impl.BasicValueNormalizedString#OWL_TYPE_STR}</td><td>{@value org.eclipse.higgins.idas.impl.BasicValueNormalizedString#XML_TYPE_STR}</td><td>{@link String} constrained to normalizedString</td><td>{@link BasicValueNormalizedString}</td></tr>
	 * <tr><td>{@value org.eclipse.higgins.idas.impl.BasicValueBoolean#OWL_TYPE_STR}</td><td>{@value org.eclipse.higgins.idas.impl.BasicValueBoolean#XML_TYPE_STR}</td><td>{@link Boolean}</td><td>{@link BasicValueBoolean}</td></tr>
	 * <tr><td>{@value org.eclipse.higgins.idas.impl.BasicValueDecimal#OWL_TYPE_STR}</td><td>{@value org.eclipse.higgins.idas.impl.BasicValueDecimal#XML_TYPE_STR}</td><td>{@link java.math.BigDecimal}</td><td>{@link BasicValueDecimal}</td></tr>
	 * <tr><td>{@value org.eclipse.higgins.idas.impl.BasicValueInteger#OWL_TYPE_STR}</td><td>{@value org.eclipse.higgins.idas.impl.BasicValueInteger#XML_TYPE_STR}</td><td>{@link java.math.BigInteger}</td><td>{@link BasicValueInteger}</td></tr>
	 * <tr><td>{@value org.eclipse.higgins.idas.impl.BasicValueNonNegativeInteger#OWL_TYPE_STR}</td><td>{@value org.eclipse.higgins.idas.impl.BasicValueNonNegativeInteger#XML_TYPE_STR}</td><td>{@link java.math.BigInteger}</td><td>{@link BasicValueNonNegativeInteger}</td></tr>
	 * <tr><td>{@value org.eclipse.higgins.idas.impl.BasicValuePositiveInteger#OWL_TYPE_STR}</td><td>{@value org.eclipse.higgins.idas.impl.BasicValuePositiveInteger#XML_TYPE_STR}</td><td>{@link java.math.BigInteger}</td><td>{@link BasicValuePositiveInteger}</td></tr>
	 * <tr><td>{@value org.eclipse.higgins.idas.impl.BasicValueNonPositiveInteger#OWL_TYPE_STR}</td><td>{@value org.eclipse.higgins.idas.impl.BasicValueNonPositiveInteger#XML_TYPE_STR}</td><td>{@link java.math.BigInteger}</td><td>{@link BasicValueNonPositiveInteger}</td></tr>
	 * <tr><td>{@value org.eclipse.higgins.idas.impl.BasicValueNegativeInteger#OWL_TYPE_STR}</td><td>{@value org.eclipse.higgins.idas.impl.BasicValueNegativeInteger#XML_TYPE_STR}</td><td>{@link java.math.BigInteger}</td><td>{@link BasicValueNegativeInteger}</td></tr>
	 * <tr><td>{@value org.eclipse.higgins.idas.impl.BasicValueFloat#OWL_TYPE_STR}</td><td>{@value org.eclipse.higgins.idas.impl.BasicValueFloat#XML_TYPE_STR}</td><td>{@link Float}</td><td>{@link BasicValueFloat}</td></tr>
	 * <tr><td>{@value org.eclipse.higgins.idas.impl.BasicValueDouble#OWL_TYPE_STR}</td><td>{@value org.eclipse.higgins.idas.impl.BasicValueDouble#XML_TYPE_STR}</td><td>{@link Double}</td><td>{@link BasicValueDouble}</td></tr>
	 * <tr><td>{@value org.eclipse.higgins.idas.impl.BasicValueLong#OWL_TYPE_STR}</td><td>{@value org.eclipse.higgins.idas.impl.BasicValueLong#XML_TYPE_STR}</td><td>{@link Long}</td><td>{@link BasicValueLong}</td></tr>
	 * <tr><td>{@value org.eclipse.higgins.idas.impl.BasicValueInt#OWL_TYPE_STR}</td><td>{@value org.eclipse.higgins.idas.impl.BasicValueInt#XML_TYPE_STR}</td><td>{@link Integer}</td><td>{@link BasicValueInteger}</td></tr>
	 * <tr><td>{@value org.eclipse.higgins.idas.impl.BasicValueShort#OWL_TYPE_STR}</td><td>{@value org.eclipse.higgins.idas.impl.BasicValueShort#XML_TYPE_STR}</td><td>{@link Short}</td><td>{@link BasicValueShort}</td></tr>
	 * <tr><td>{@value org.eclipse.higgins.idas.impl.BasicValueByte#OWL_TYPE_STR}</td><td>{@value org.eclipse.higgins.idas.impl.BasicValueByte#XML_TYPE_STR}</td><td>{@link Byte}</td><td>{@link BasicValueByte}</td></tr>
	 * <tr><td>{@value org.eclipse.higgins.idas.impl.BasicValueUnsignedLong#OWL_TYPE_STR}</td><td>{@value org.eclipse.higgins.idas.impl.BasicValueUnsignedLong#XML_TYPE_STR}</td><td>{@link java.math.BigInteger}</td><td>{@link BasicValueUnsignedLong}</td></tr>
	 * <tr><td>{@value org.eclipse.higgins.idas.impl.BasicValueUnsignedInt#OWL_TYPE_STR}</td><td>{@value org.eclipse.higgins.idas.impl.BasicValueUnsignedInt#XML_TYPE_STR}</td><td>{@link java.math.BigInteger}</td><td>{@link BasicValueUnsignedInt}</td></tr>
	 * <tr><td>{@value org.eclipse.higgins.idas.impl.BasicValueUnsignedShort#OWL_TYPE_STR}</td><td>{@value org.eclipse.higgins.idas.impl.BasicValueUnsignedShort#XML_TYPE_STR}</td><td>{@link java.math.BigInteger}</td><td>{@link BasicValueUnsignedShort}</td></tr>
	 * <tr><td>{@value org.eclipse.higgins.idas.impl.BasicValueUnsignedByte#OWL_TYPE_STR}</td><td>{@value org.eclipse.higgins.idas.impl.BasicValueUnsignedByte#XML_TYPE_STR}</td><td>{@link java.math.BigInteger}</td><td>{@link BasicValueUnsignedByte}</td></tr>
	 * <tr><td>{@value org.eclipse.higgins.idas.impl.BasicValueHexBinary#OWL_TYPE_STR}</td><td>{@value org.eclipse.higgins.idas.impl.BasicValueHexBinary#XML_TYPE_STR}</td><td>{@link java.nio.ByteBuffer}</td><td>{@link BasicValueHexBinary}</td></tr>
	 * <tr><td>{@value org.eclipse.higgins.idas.impl.BasicValueBase64Binary#OWL_TYPE_STR}</td><td>{@value org.eclipse.higgins.idas.impl.BasicValueBase64Binary#XML_TYPE_STR}</td><td>{@link java.nio.ByteBuffer}</td><td>{@link BasicValueBase64Binary}</td></tr>
	 * <tr><td>{@value org.eclipse.higgins.idas.impl.BasicValueDateTime#OWL_TYPE_STR}</td><td>{@value org.eclipse.higgins.idas.impl.BasicValueDateTime#XML_TYPE_STR}</td><td>{@link java.util.Date}</td><td>{@link BasicValueDateTime}</td></tr>
	 * <tr><td>{@value org.eclipse.higgins.idas.impl.BasicValueTime#OWL_TYPE_STR}</td><td>{@value org.eclipse.higgins.idas.impl.BasicValueTime#XML_TYPE_STR}</td><td>{@link java.util.Date}</td><td>{@link BasicValueTime}</td></tr>
	 * <tr><td>{@value org.eclipse.higgins.idas.impl.BasicValueDate#OWL_TYPE_STR}</td><td>{@value org.eclipse.higgins.idas.impl.BasicValueDate#XML_TYPE_STR}</td><td>{@link java.util.Date}</td><td>{@link BasicValueDate}</td></tr>
	 * <tr><td>{@value org.eclipse.higgins.idas.impl.BasicValueGYearMonth#OWL_TYPE_STR}</td><td>{@value org.eclipse.higgins.idas.impl.BasicValueGYearMonth#XML_TYPE_STR}</td><td>{@link java.util.Date}</td><td>{@link BasicValueGYearMonth}</td></tr>
	 * <tr><td>{@value org.eclipse.higgins.idas.impl.BasicValueGYear#OWL_TYPE_STR}</td><td>{@value org.eclipse.higgins.idas.impl.BasicValueGYear#XML_TYPE_STR}</td><td>{@link java.util.Date}</td><td>{@link BasicValueGYear}</td></tr>
	 * <tr><td>{@value org.eclipse.higgins.idas.impl.BasicValueGMonthDay#OWL_TYPE_STR}</td><td>{@value org.eclipse.higgins.idas.impl.BasicValueGMonthDay#XML_TYPE_STR}</td><td>{@link java.util.Date}</td><td>{@link BasicValueGMonthDay}</td></tr>
	 * <tr><td>{@value org.eclipse.higgins.idas.impl.BasicValueGDay#OWL_TYPE_STR}</td><td>{@value org.eclipse.higgins.idas.impl.BasicValueGDay#XML_TYPE_STR}</td><td>{@link java.util.Date}</td><td>{@link BasicValueGDay}</td></tr>
	 * <tr><td>{@value org.eclipse.higgins.idas.impl.BasicValueGMonth#OWL_TYPE_STR}</td><td>{@value org.eclipse.higgins.idas.impl.BasicValueGMonth#XML_TYPE_STR}</td><td>{@link java.util.Date}</td><td>{@link BasicValueGMonth}</td></tr>
	 * <tr><td>{@value org.eclipse.higgins.idas.impl.BasicValueAnyURI#OWL_TYPE_STR}</td><td>{@value org.eclipse.higgins.idas.impl.BasicValueAnyURI#XML_TYPE_STR}</td><td>{@link URI}</td><td>{@link BasicValueAnyURI}</td></tr>
	 * <tr><td>{@value org.eclipse.higgins.idas.impl.BasicValueToken#OWL_TYPE_STR}</td><td>{@value org.eclipse.higgins.idas.impl.BasicValueToken#XML_TYPE_STR}</td><td>{@link String} constrained to token</td><td>{@link BasicValueToken}</td></tr>
	 * <tr><td>{@value org.eclipse.higgins.idas.impl.BasicValueLanguage#OWL_TYPE_STR}</td><td>{@value org.eclipse.higgins.idas.impl.BasicValueLanguage#XML_TYPE_STR}</td><td>{@link String} constrained to language</td><td>{@link BasicValueLanguage}</td></tr>
	 * <tr><td>{@value org.eclipse.higgins.idas.impl.BasicValueNMTOKEN#OWL_TYPE_STR}</td><td>{@value org.eclipse.higgins.idas.impl.BasicValueNMTOKEN#XML_TYPE_STR}</td><td>{@link String} constrained to NMTOKEN</td><td>{@link BasicValueNMTOKEN}</td></tr>
	 * <tr><td>{@value org.eclipse.higgins.idas.impl.BasicValueName#OWL_TYPE_STR}</td><td>{@value org.eclipse.higgins.idas.impl.BasicValueName#XML_TYPE_STR}</td><td>{@link String} constrained to Name</td><td>{@link BasicValueName}</td></tr>
	 * <tr><td>{@value org.eclipse.higgins.idas.impl.BasicValueNCName#OWL_TYPE_STR}</td><td>{@value org.eclipse.higgins.idas.impl.BasicValueNCName#XML_TYPE_STR}</td><td>{@link String} constrained to NCName</td><td>{@link BasicValueNCName}</td></tr>
	 * </table>
	 * @throws IdASException
	 */
	public Object getData() throws IdASException;
	
}
