/*******************************************************************************
 * Copyright (c) 2006 Novell, Inc..
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *    Jim Sermersheim - Initial cut
 *******************************************************************************/
package org.eclipse.higgins.idas.impl;

import java.net.URI;
import java.util.HashSet;
import java.util.Vector;

import org.eclipse.higgins.idas.IAttribute;
import org.eclipse.higgins.idas.IHasMetadata;
import org.eclipse.higgins.idas.IMetadata;
import org.eclipse.higgins.idas.IPropertyValue;
import org.eclipse.higgins.idas.IdASException;

/**
 * Implements IAttribute using {@link BasicProperty} and {@link BasicMetadata}
 */
public class BasicAttribute implements IAttribute {
	BasicMetadataSet _metaSetImpl;
	BasicProperty _propImpl;
	
	/**
	 * 
	 */
	public BasicAttribute(URI type) {
		_propImpl = new BasicProperty(type);
		_metaSetImpl = new BasicMetadataSet();
	}

	/**
	 * 
	 */
	public BasicAttribute(URI type, IPropertyValue value) {
		_propImpl = new BasicProperty(type, value);
		_metaSetImpl = new BasicMetadataSet();
	}

	/**
	 * 
	 */
	public BasicAttribute(URI type, Vector<IPropertyValue> values) {
		_propImpl = new BasicProperty(type, values);
		_metaSetImpl = new BasicMetadataSet();
	}

	/**
	 * 
	 */
	public BasicAttribute(URI type, Iterable<IPropertyValue> values) {
		_propImpl = new BasicProperty(type, values);
		_metaSetImpl = new BasicMetadataSet();
	}

	/**
	 * 
	 */
	public BasicAttribute(URI type, IPropertyValue value, HashSet<IMetadata> metadataSet) {
		_propImpl = new BasicProperty(type, value);
		_metaSetImpl = new BasicMetadataSet(metadataSet);
	}

	/**
	 * 
	 */
	public BasicAttribute(URI type, Vector<IPropertyValue> values, HashSet<IMetadata> metadataSet) {
		_propImpl = new BasicProperty(type, values);
		_metaSetImpl = new BasicMetadataSet(metadataSet);
	}

	/**
	 * @see org.eclipse.higgins.idas.IProperty#getType()
	 */
	public URI getType() throws IdASException {
		return _propImpl.getType();
	}
	
	/**
	 * @see org.eclipse.higgins.idas.IProperty#getValue()
	 */
	public IPropertyValue getValue() throws IdASException {
		return _propImpl.getValue();
	}

	/**
	 * @see org.eclipse.higgins.idas.IProperty#getValues()
	 */
	public Iterable<IPropertyValue> getValues() throws IdASException {
		return _propImpl.getValues();
	}

	/**
	 * @see org.eclipse.higgins.idas.IProperty#setValue(IPropertyValue)
	 */
	public void setValue(IPropertyValue value) throws IdASException {
		_propImpl.setValue(value);
	}

	/**
	 * @see IHasMetadata#createMetadata(URI, IPropertyValue)
	 */
	public IMetadata createMetadata(URI type, IPropertyValue value) throws IdASException {
		return _metaSetImpl.createMetadata(type, value);
	}

	/**
	 * @see IHasMetadata#addMetadata(IMetadata)
	 */
	public void addMetadata(IMetadata metadata) throws IdASException {
		_metaSetImpl.addMetadata(metadata);
	}

	/**
	 * @see IHasMetadata#removeMetadata(IMetadata)
	 */
	public void removeMetadata(IMetadata metadata) throws IdASException {
		_metaSetImpl.removeMetadata(metadata);
	}
		
	/** 
	 * @see IHasMetadata#getMetadataSet()
	 */
	public Iterable<IMetadata> getMetadataSet() throws IdASException {
		return _metaSetImpl.getMetadataSet();
	}

}
