/*******************************************************************************
 * Copyright (c) 2006 Novell, Inc..
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *    Jim Sermersheim - Initial cut
 *******************************************************************************/

package org.eclipse.higgins.idas.impl;

import java.net.URI;
import java.util.HashMap;

import org.eclipse.higgins.idas.IAttribute;
import org.eclipse.higgins.idas.IHasAttributes;
import org.eclipse.higgins.idas.IPropertyValue;
import org.eclipse.higgins.idas.IdASException;

/**
 * Basic implementation of {@link IHasAttributes}.
 * This class uses a {@link HashMap} of {@link URI} and {@link IAttribute} to hold the attributes.
 * 
 */
public class BasicAttributeSet implements IHasAttributes {
	HashMap<URI, IAttribute> _attrs;

	public BasicAttributeSet() {
		_attrs = new HashMap<URI, IAttribute>();
	}

	public BasicAttributeSet(Iterable<IAttribute> attrs) {
		for (IAttribute attr : attrs) {
			try {
				_attrs.put(attr.getType(), attr);
			} catch (IdASException e) {
				throw new IllegalArgumentException (e);
			}
		}
	}

	public IAttribute createAttribute(URI type, IPropertyValue value)
			throws IdASException {
		BasicAttribute attr = new BasicAttribute(type, value);
		addAttribute(attr);
		return attr;
	}

	public IAttribute createAttribute(URI type, Iterable<IPropertyValue> values)
	throws IdASException {
		BasicAttribute attr = new BasicAttribute(type, values);
		addAttribute(attr);
		return attr;
	}
	
	public void addAttribute(IAttribute attribute) throws IdASException {
		_attrs.put(attribute.getType(), attribute);
	}

	public void removeAttribute(IAttribute attribute) throws IdASException {
		_attrs.remove(attribute.getType());
	}

	public Iterable<IAttribute> getAttributes() throws IdASException {
		return _attrs.values();
	}

	public IAttribute getAttribute(URI attrID) throws IdASException {
		return _attrs.get(attrID);
	}

}
