package org.eclipse.higgins.idas.impl;

import java.util.Vector;

import org.eclipse.higgins.idas.BadFilterException;
import org.eclipse.higgins.idas.IFilter;
import org.eclipse.higgins.idas.IFilterAssertion;
import org.eclipse.higgins.idas.IFilterAttributeAssertion;
import org.eclipse.higgins.idas.IFilterCUIDAssertion;
import org.eclipse.higgins.idas.IFilterMetadataAssertion;
import org.eclipse.higgins.idas.IFilterRelationshipAssertion;
import org.eclipse.higgins.idas.IFilterTypeAssertion;
import org.eclipse.higgins.idas.IdASException;

public class BasicFilter implements IFilter {
	private IFilterAssertion _assertion = null;
	private String _operator = null;
	private Vector<IFilter> _filters = null;
	
	public BasicFilter() {
		super();
	}

	public void setAssertion(IFilterAssertion assertion) throws IdASException {
		if ((_operator == null) && (_filters ==null)) {
			_assertion = assertion;
		} else {
			throw new BadFilterException("Assertion cannot be added when operator or filter is present");
		}
	}

	/**
	 * @return assertion set by calling {@link #setAssertion(IFilterAssertion)}. May be null.
	 * @throws IdASException
	 */
	public IFilterAssertion getAssertion() throws IdASException {
		return _assertion;
	}

	public void setOperator(String operator) throws IdASException {
		if (_assertion == null) {
			_operator = operator;
		} else {
			throw new BadFilterException("Operator cannot be added when assertion is present");
		}
	}

	/**
	 * @return operator set by calling {@link #setOperator(String)}. May be null.
	 * @throws IdASException
	 */
	public String getOperator() throws IdASException {
		return _operator;
	}

	public void addFilter(IFilter filter) throws IdASException {
		if (_assertion == null) {
			if (_filters == null)
				_filters = new Vector<IFilter>();
			_filters.add(filter);
		} else {
			throw new BadFilterException("Filter cannot be added when assertion is present");
		}
	}

	/**
	 * 
	 * @return an iteration of the filters set by {@link #addFilter(IFilter)}. May be null
	 * @throws IdASException
	 */
	public Iterable<IFilter> getFilters() throws IdASException {
		return _filters;
	}

	public IFilterAttributeAssertion createAttributeAssertion()
			throws IdASException {
		return new BasicFilterAttributeAssertion();
	}

	public IFilterCUIDAssertion createCUIDAssertion() throws IdASException {
		return new BasicFilterCUIDAssertion();
	}

	public IFilterMetadataAssertion createMetadataAssertion()
			throws IdASException {
		return new BasicFilterMetadataAssertion();
	}

	public IFilterRelationshipAssertion createRelationshipAssertion()
			throws IdASException {
		return new BasicFilterRelationshipAssertion();
	}

	public IFilterTypeAssertion createTypeAssertion() throws IdASException {
		return new BasicFilterTypeAssertion();
	}

}
