/*******************************************************************************
 * Copyright (c) 2006 Novell, Inc..
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *    Jim Sermersheim - Initial cut
 *******************************************************************************/
package org.eclipse.higgins.idas.impl;

import java.net.URI;
import java.util.HashSet;

import org.eclipse.higgins.idas.IHasMetadata;
import org.eclipse.higgins.idas.IMetadata;
import org.eclipse.higgins.idas.IPropertyValue;
import org.eclipse.higgins.idas.IdASException;

/**
 * Implements {@link IHasMetadata} using a {@link HashSet}.  This is used by other basic implementations which implement subinterfaces of {@link org.eclipse.higgins.idas.IHasMetadata}.  
 *
 */
public class BasicMetadataSet implements IHasMetadata {
	
	HashSet<IMetadata> _metadataSet;
	
	/**
	 * 
	 */
	public BasicMetadataSet() {
		_metadataSet = new HashSet<IMetadata>();
	}

	/**
	 * 
	 */
	public BasicMetadataSet(HashSet<IMetadata> metadataSet) {
		_metadataSet = metadataSet;
	}

	/**
	 * @see IHasMetadata#createMetadata(URI, IPropertyValue)
	 */
	public IMetadata createMetadata(URI type, IPropertyValue value) throws IdASException {
		return new BasicMetadata(type, value);
	}

	/**
	 * @see IHasMetadata#addMetadata(IMetadata)
	 */
	public void addMetadata(IMetadata metadata) throws IdASException {
		_getMetadataSet().add(metadata);
	}

	/**
	 * @see IHasMetadata#removeMetadata(IMetadata)
	 */
	public void removeMetadata(IMetadata metadata) throws IdASException {
		_getMetadataSet().remove(metadata);
	}
		
	/** 
	 * @see IHasMetadata#getMetadataSet()
	 */
	public Iterable<IMetadata> getMetadataSet() throws IdASException {
		return _getMetadataSet();
	}
	private HashSet<IMetadata> _getMetadataSet() throws IdASException {
		if (_metadataSet == null)
			_metadataSet = new HashSet<IMetadata>();
		return _metadataSet;
	}

}
