/*******************************************************************************
 * Copyright (c) 2006 Novell, Inc..
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *    Jim Sermersheim
 *******************************************************************************/
package org.eclipse.higgins.idas.impl;

import java.net.URI;
import java.util.Vector;

import org.eclipse.higgins.idas.IProperty;
import org.eclipse.higgins.idas.IPropertyValue;
import org.eclipse.higgins.idas.IdASException;

/**
 * Basic implementation of {@link IProperty}.
 * TODO (Impl)(Doc): Add comments. Specifically regarding the mutability of _value
 */
public class BasicProperty implements IProperty {

	private URI _type;
	private Vector<IPropertyValue> _values;
	
	/**
	 * 
	 */
	public BasicProperty(URI type) {
		_type = type;
		_values = new Vector<IPropertyValue>();
	}

	/**
	 * 
	 */
	public BasicProperty(URI type, IPropertyValue value) {
		_type = type;
		_values = new Vector<IPropertyValue>();
		_values.add(value);
	}

	/**
	 * 
	 */
	public BasicProperty(URI type, Vector<IPropertyValue> values) {
		_type = type;
		_values = values;
	}

	/**
	 * 
	 */
	public BasicProperty(URI type, Iterable<IPropertyValue> values) {
		_type = type;
		for (IPropertyValue value : values) {
			_values.add(value);
		}
	}

	public URI getType() throws IdASException {
		return _type;
	}

	public IPropertyValue getValue() throws IdASException {
		return _values.firstElement();
	}

	public void setValue(IPropertyValue value) throws IdASException {
		_values.add(value);
	}

	public Iterable<IPropertyValue> getValues() throws IdASException {
		return _values;
	}

}
