/*******************************************************************************
 * Copyright (c) 2006 Novell, Inc..
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *    Jim Sermersheim - Initial cut
 *******************************************************************************/

package org.eclipse.higgins.idas.impl;

import java.net.URI;
import java.util.HashMap;

import org.eclipse.higgins.idas.IProperty;
import org.eclipse.higgins.idas.IHasProperties;
import org.eclipse.higgins.idas.IPropertyValue;
import org.eclipse.higgins.idas.IdASException;

/**
 * Basic implementation of {@link IHasProperties}.
 * This class uses a {@link HashMap} of {@link URI} and {@link IProperty} to hold the properties.
 * 
 */
public class BasicPropertySet implements IHasProperties {
	HashMap<URI, IProperty> _props;

	public BasicPropertySet() {
		_props = new HashMap<URI, IProperty>();
	}

	public BasicPropertySet(Iterable<IProperty> props) {
		for (IProperty prop : props) {
			try {
				_props.put(prop.getType(), prop);
			} catch (IdASException e) {
				throw new IllegalArgumentException (e);
			}
		}
	}

	public IProperty createProperty(URI type, IPropertyValue value)
			throws IdASException {
		BasicProperty prop = new BasicProperty(type, value);
		addProperty(prop);
		return prop;
	}

	public IProperty createProperty(URI type, Iterable<IPropertyValue> values)
	throws IdASException {
		BasicProperty prop = new BasicProperty(type, values);
		addProperty(prop);
		return prop;
	}
	
	public void addProperty(IProperty property) throws IdASException {
		_props.put(property.getType(), property);
	}

	public void removeProperty(IProperty property) throws IdASException {
		_props.remove(property.getType());
	}

	public Iterable<IProperty> getProperties() throws IdASException {
		return _props.values();
	}

	public IProperty getProperty(URI attrID) throws IdASException {
		return _props.get(attrID);
	}

}
