/*******************************************************************************
 * Copyright (c) 2006 Novell, Inc..
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *    Jim Sermersheim - Initial cut of interface
 *******************************************************************************/

package org.eclipse.higgins.idas.impl;

import java.net.URI;
import java.net.URISyntaxException;

import org.eclipse.higgins.idas.IPropertyValue;
import org.eclipse.higgins.idas.ISimpleValue;
import org.eclipse.higgins.idas.IdASException;

public class BasicSimpleValue  extends AbstractSimpleValue implements ISimpleValue {
	
	public static final String XML_TYPE_STR = "any";
	public static final String OWL_TYPE_STR = XML_TYPE_STR + AbstractSimpleValue.OWL_TYPE_SUFFIX;
	public static final String ATTR_VALUE_URI_STR = IPropertyValue.BASE_OWL_URI + OWL_TYPE_STR;
	public static final String ATTR_VALUE_TYPE_URI_STR = ISimpleValue.BASE_XML_SCHEMA_URI + XML_TYPE_STR;

	private Object _value;
	private URI _type = null;

	public BasicSimpleValue(Object value) {
		_value = value;
	}

	public boolean isSimple() throws IdASException {
		return true;
	}

	/**
	 *	Sets the type for this value 
	 */
	public void setType(URI type) throws IdASException {
		_type = type;
	}

	/**
	 * Returns a URI for {@value #ATTR_VALUE_TYPE_URI_STR} or internal type if set by {@link #setType(URI)}
	 */
	public URI getType() throws IdASException {
		if (_type != null)
			return _type;
		try {
			return new URI(ATTR_VALUE_TYPE_URI_STR);
		} catch (URISyntaxException e) {
			throw new IdASException(e);
		}
	}

	public Object getData() throws IdASException {
		return _value;
	}
}
