/*******************************************************************************
 * Copyright (c) 2006 Novell, Inc..
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *    Jim Sermersheim - Initial cut
 *******************************************************************************/

package org.eclipse.higgins.idas.impl;

import java.net.URI;
import java.net.URISyntaxException;
import java.nio.ByteBuffer;

import org.eclipse.higgins.idas.IPropertyValue;
import org.eclipse.higgins.idas.ISimpleValue;
import org.eclipse.higgins.idas.IdASException;

import sun.misc.BASE64Encoder;

/**
 * Currently uses sun.misc.BASE64Encoder which is not officially supported.
 * This will be replaced as soon as licensing of other source is approved. 
 *
 */
public class BasicValueBase64Binary extends AbstractSimpleValue implements ISimpleValue {

	public static final String XML_TYPE_STR = "base64Binary";
	public static final String OWL_TYPE_STR = XML_TYPE_STR + AbstractSimpleValue.OWL_TYPE_SUFFIX;
	public static final String ATTR_VALUE_URI_STR = IPropertyValue.BASE_OWL_URI + OWL_TYPE_STR; 
	public static final String ATTR_VALUE_TYPE_URI_STR = ISimpleValue.BASE_XML_SCHEMA_URI + XML_TYPE_STR;

	private ByteBuffer _bytes; 
	
	/**
	 * Uses the specified byte array to build this object.
	 * @param bytes array of bytes used to back this object
	 */
	public BasicValueBase64Binary(byte[] bytes) {
		_bytes = ByteBuffer.wrap(bytes);
	}

	public String getLexical() throws IdASException {
		return getCanonical();
	}

	/**
	 * TODO (Impl): make sure this meets the canonical rules for xsd:base64Binary
	 */
	public String getCanonical() throws IdASException {
		BASE64Encoder encoder = new BASE64Encoder();
		return encoder.encode(_bytes.array());
	}

	/**
	 * Returns the {@link ByteBuffer} backing this value.
	 */
	public Object getData() throws IdASException {
		return _bytes;		
	}
	
	/**
	 * Returns a URI for {@value #ATTR_VALUE_TYPE_URI_STR}
	 */
	public URI getType() throws IdASException {
		try {
			return new URI(ATTR_VALUE_TYPE_URI_STR);
		} catch (URISyntaxException e) {
			throw new IdASException(e);
		}
	}

}
