/*******************************************************************************
 * Copyright (c) 2006 Novell, Inc..
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *    Jim Sermersheim - Initial cut
 *******************************************************************************/

package org.eclipse.higgins.idas.impl;

import java.net.URI;
import java.net.URISyntaxException;
import java.text.SimpleDateFormat;
import java.util.Date;

import org.eclipse.higgins.idas.IPropertyValue;
import org.eclipse.higgins.idas.ISimpleValue;
import org.eclipse.higgins.idas.IdASException;

public class BasicValueDateTime extends AbstractSimpleValue implements ISimpleValue {
	
	public static final String XML_TYPE_STR = "dateTime";
	public static final String OWL_TYPE_STR = XML_TYPE_STR + AbstractSimpleValue.OWL_TYPE_SUFFIX;
	public static final String ATTR_VALUE_URI_STR = IPropertyValue.BASE_OWL_URI + OWL_TYPE_STR; 
	public static final String ATTR_VALUE_TYPE_URI_STR = ISimpleValue.BASE_XML_SCHEMA_URI + XML_TYPE_STR;

	private Date _value;
	private int _formatUsed;
	
	public BasicValueDateTime(String value) {
		_setValue(_parseString(value));
	}
	
	public String getLexical() throws IdASException {
		SimpleDateFormat sdf = new SimpleDateFormat(_getAllowedFormats()[_formatUsed]);
		return sdf.format(_value);
	}

	public String getCanonical() throws IdASException {
		SimpleDateFormat sdf = new SimpleDateFormat(_getAllowedFormats()[0]);
		return sdf.format(_value);
	}

	public Object getData() throws IdASException {
		return _value;
	}

	protected void _setValue(Date value) {
		_value = value;
	}
	
	private Date _parseString(String value) {
		SimpleDateFormat sdf = new SimpleDateFormat();
		String[] formats = _getAllowedFormats();
		Date date = null;
		for (_formatUsed = 0; _formatUsed < formats.length; _formatUsed++) {
			try {
				sdf.applyPattern(formats[_formatUsed]);
				date = sdf.parse(value);
			} catch(java.text.ParseException e) {
				// try next pattern
			}
			break;
		}
		return date;
	}
	
	/**
	 * @return a String array of {@link java.text.SimpleDateFormat} 
	 * 			Date and Time Pattern strings where the first string 
	 * 			represents the canonical representation and subsequent 
	 * 			strings represent other lexical representations 
	 */
	protected String[] _getAllowedFormats() {
		//'-'? yyyy '-' mm '-' dd 'T' hh ':' mm ':' ss ('.' s+)? (zzzzzz)?		
		return new String[]{"yyyy-MM-dd'T'HH:mm:ss.S'Z'",
							"yyyy-MM-dd'T'HH:mm:ss'Z'",
							"yyyy-MM-dd'T'HH:mm:ss.SZ",							
							"yyyy-MM-dd'T'HH:mm:ssZ"};
	}

	/**
	 * Returns a URI for {@value #ATTR_VALUE_TYPE_URI_STR}
	 */
	public URI getType() throws IdASException {
		try {
			return new URI(ATTR_VALUE_TYPE_URI_STR);
		} catch (URISyntaxException e) {
			throw new IdASException(e);
		}
	}
}
