/*******************************************************************************
 * Copyright (c) 2006 Novell, Inc..
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *    Jim Sermersheim - Initial cut
 *******************************************************************************/

package org.eclipse.higgins.idas.impl;

import java.math.BigDecimal;
import java.net.URI;
import java.net.URISyntaxException;

import org.eclipse.higgins.idas.IPropertyValue;
import org.eclipse.higgins.idas.ISimpleValue;
import org.eclipse.higgins.idas.IdASException;

public class BasicValueDecimal extends AbstractSimpleValue implements ISimpleValue {
	
	public static final String XML_TYPE_STR = "decimal";
	public static final String OWL_TYPE_STR = XML_TYPE_STR + AbstractSimpleValue.OWL_TYPE_SUFFIX;
	public static final String ATTR_VALUE_URI_STR = IPropertyValue.BASE_OWL_URI + OWL_TYPE_STR; 
	public static final String ATTR_VALUE_TYPE_URI_STR = ISimpleValue.BASE_XML_SCHEMA_URI + XML_TYPE_STR;

	private BigDecimal _value;

	public BasicValueDecimal(String value) {
		_value = new BigDecimal(value);
	}

	public String getLexical() throws IdASException {
		return getCanonical();
	}

	/**
	 * Returns a string representation of teh backing {@link BigDecimal} without an exponent field.
	 */
	public String getCanonical() throws IdASException {
		return _value.toPlainString();
	}

	/**
	 * Returns the {@link BigDecimal} backing this value.
	 */
	public Object getData() throws IdASException {
		return _value;
	}

	/**
	 * Returns a URI for {@value #ATTR_VALUE_TYPE_URI_STR}
	 */
	public URI getType() throws IdASException {
		try {
			return new URI(ATTR_VALUE_TYPE_URI_STR);
		} catch (URISyntaxException e) {
			throw new IdASException(e);
		}
	}

}
