/*******************************************************************************
 * Copyright (c) 2006 Novell, Inc..
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *    Jim Sermersheim - Initial cut
 *******************************************************************************/

package org.eclipse.higgins.idas.impl;

import java.net.URI;
import java.net.URISyntaxException;
import java.nio.ByteBuffer;

import org.eclipse.higgins.idas.IPropertyValue;
import org.eclipse.higgins.idas.ISimpleValue;
import org.eclipse.higgins.idas.IdASException;

/**
 *
 */
public class BasicValueHexBinary extends AbstractSimpleValue implements ISimpleValue {
	
	public static final String XML_TYPE_STR = "hexBinary";
	public static final String OWL_TYPE_STR = XML_TYPE_STR + AbstractSimpleValue.OWL_TYPE_SUFFIX;
	public static final String ATTR_VALUE_URI_STR = IPropertyValue.BASE_OWL_URI + OWL_TYPE_STR; 
	public static final String ATTR_VALUE_TYPE_URI_STR = ISimpleValue.BASE_XML_SCHEMA_URI + XML_TYPE_STR;

	private ByteBuffer _value; 
	
	/**
	 * Uses the specified byte array to build this object.
	 * @param bytes array of bytes used to back this object
	 */
	public BasicValueHexBinary(byte[] bytes) {
		_value = ByteBuffer.wrap(bytes);
	}

	public String getLexical() throws IdASException {
		return _toHexString();
	}

	/**
	 * TODO (Impl): make sure this meets the canonical rules for xsd:base64Binary
	 */
	public String getCanonical() throws IdASException {
		return _toHexString().toUpperCase();
	}

	/**
	 * Returns the {@link ByteBuffer} backing this value.
	 */
	public Object getData() throws IdASException {
		return _value;
	}
	
	private String _toHexString() {
		byte[] array = _value.array();
		StringBuffer sb = new StringBuffer(array.length * 2);  
		for (int iLoop = 0; iLoop < array.length; iLoop++) {
			sb.append(Integer.toHexString(array[iLoop]));
		}
		return sb.toString();
	}

	/**
	 * Returns a URI for {@value #ATTR_VALUE_TYPE_URI_STR}
	 */
	public URI getType() throws IdASException {
		try {
			return new URI(ATTR_VALUE_TYPE_URI_STR);
		} catch (URISyntaxException e) {
			throw new IdASException(e);
		}
	}

}
