/*******************************************************************************
 * Copyright (c) 2006 Novell, Inc..
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *    Jim Sermersheim - Initial cut
 *******************************************************************************/

package org.eclipse.higgins.idas.impl;

import java.math.BigInteger;
import java.net.URI;
import java.net.URISyntaxException;

import org.eclipse.higgins.idas.IPropertyValue;
import org.eclipse.higgins.idas.ISimpleValue;
import org.eclipse.higgins.idas.IdASException;

/**
 * TODO (Impl): make sure getCanonical() meets the canonical rules for xsd:integer. Nothing in the BigInteger Javadoc leads me to believe it's incorrect.
 */
public class BasicValueInteger extends AbstractSimpleValue implements ISimpleValue {
	
	public static final String XML_TYPE_STR = "integer";
	public static final String OWL_TYPE_STR = XML_TYPE_STR + AbstractSimpleValue.OWL_TYPE_SUFFIX;
	public static final String ATTR_VALUE_URI_STR = IPropertyValue.BASE_OWL_URI + OWL_TYPE_STR; 
	public static final String ATTR_VALUE_TYPE_URI_STR = ISimpleValue.BASE_XML_SCHEMA_URI + XML_TYPE_STR;

	private BigInteger _value;
	
	public BasicValueInteger(String value) {
		_setValue(new BigInteger(value));
	}

	/**
	 * Returns the {@link BigInteger} backing this value
	 */
	public Object getData() throws IdASException {
		return _value;
	}

	protected void _setValue (BigInteger value) {
		_value = value;
	}

	/**
	 * Returns a URI for {@value #ATTR_VALUE_TYPE_URI_STR}
	 */
	public URI getType() throws IdASException {
		try {
			return new URI(ATTR_VALUE_TYPE_URI_STR);
		} catch (URISyntaxException e) {
			throw new IdASException(e);
		}
	}

}
